@@ -47,7 +47,7 @@ class Job:
         self.args = args
         if job_id == None:
             if only_once:
-                self.job_id = uuid4()
+                self.job_id = f"{func.__module__}.{func.__name__}__" + uuid4()
             else:
                 self.job_id = f"{func.__module__}.{func.__name__}"
         else:
